==> slurm-llnl_16.05.9.orig.tar.gz: slurm-slurm-16-05-9-1/src/slurmd/common/setproctitle.h <==
/*****************************************************************************\
 * src/slurmd/common/setproctitle.h - Emulation of BSD setproctitle()
 *****************************************************************************
 *  Copyright (C) 2002 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Mark Grondona <mgrondona@llnl.gov>.
 *  CODE-OCEC-09-009. All rights reserved.
 *
 *  This file is part of SLURM, a resource management program.
 *  For details, see <http://slurm.schedmd.com/>.
 *  Please also read the included file: DISCLAIMER.
 *
 *  SLURM is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission
 *  to link the code of portions of this program with the OpenSSL library under
 *  certain conditions as described in each individual source file, and
 *  distribute linked combinations including the two. You must obey the GNU
 *  General Public License in all respects for all of the code used other than
 *  OpenSSL. If you modify file(s) with this exception, you may extend this
 *  exception to your version of the file(s), but you are not obligated to do
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in
 *  the program, then also delete it here.
 *
 *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with SLURM; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\*****************************************************************************/

#ifndef _BSD_SETPROCTITLE_H
#define _BSD_SETPROCTITLE_H

#if HAVE_CONFIG_H
#  include "config.h"
#endif

#if defined(__FreeBSD__)
extern void setproctitle(const char *fmt, ...)
  __attribute__ ((format (printf, 1, 2)));
#endif

#ifndef HAVE_SETPROCTITLE
extern void setproctitle(const char *fmt, ...)
  __attribute__ ((format (printf, 1, 2)));
#endif

extern void init_setproctitle(int argc, char *argv[]);
extern void fini_setproctitle(void);

#endif /* _BSD_SETPROCTITLE_H */

==> slurm-llnl_17.11.2.orig.tar.gz: slurm-slurm-17-11-2-1/src/slurmd/common/setproctitle.h <==
/*****************************************************************************\
 * src/slurmd/common/setproctitle.h - Emulation of BSD setproctitle()
 *****************************************************************************
 *  Copyright (C) 2002 The Regents of the University of California.
 *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
 *  Written by Mark Grondona <mgrondona@llnl.gov>.
 *  CODE-OCEC-09-009. All rights reserved.
 *
 *  This file is part of SLURM, a resource management program.
 *  For details, see <https://slurm.schedmd.com/>.
 *  Please also read the included file: DISCLAIMER.
 *
 *  SLURM is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission
 *  to link the code of portions of this program with the OpenSSL library under
 *  certain conditions as described in each individual source file, and
 *  distribute linked combinations including the two. You must obey the GNU
 *  General Public License in all respects for all of the code used other than
 *  OpenSSL. If you modify file(s) with this exception, you may extend this
 *  exception to your version of the file(s), but you are not obligated to do
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in
 *  the program, then also delete it here.
 *
 *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with SLURM; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\*****************************************************************************/

#ifndef _BSD_SETPROCTITLE_H
#define _BSD_SETPROCTITLE_H

#include "config.h"

#if defined(__FreeBSD__)
extern void setproctitle(const char *fmt, ...)
  __attribute__ ((format (printf, 1, 2)));
#endif

#ifndef HAVE_SETPROCTITLE
extern void setproctitle(const char *fmt, ...)
  __attribute__ ((format (printf, 1, 2)));
#endif

extern void init_setproctitle(int argc, char **argv);
extern void fini_setproctitle(void);

#endif /* _BSD_SETPROCTITLE_H */
